/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Quickfile extension for Thunderbird.
 *
 * The Initial Developer of the Original Code is Paul Tomlin.
 * Portions created by the Initial Developer are Copyright (C) 2005, 2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Paul Tomlin
 *  Mark Shuttleworth
 *
 * ***** END LICENSE BLOCK ***** */

/* $Id: optionsGeneral.js,v 1.2 2006/11/20 10:32:31 paultomlin Exp $ */

var gGeneralPane =
{
  onPaneLoad: function _onPaneLoad ()
  {

    document.getElementById('quickfile.search.root.account.radio').value =
      document.getElementById('quickfile.search.root.account.menulist').value;

    // it would appear that the search root for the XPFE version is remembered!
    var autoCompleteSession = document.getElementById('quickfile.search.root.textbox').getSession(0);
    if (autoCompleteSession && typeof autoCompleteSession.QueryInterface == 'function') {
      autoCompleteSession.QueryInterface(nsICategoryManager)
                         .addCategoryEntry('quickfile', 'searchRoot', QF_SEARCHROOT_ALL, false, true);
    }

    var uri;
    var folder;

    uri = document.getElementById('quickfile.search.root').value;
    switch (uri) {
      case QF_SEARCHROOT_ALL:
      case QF_SEARCHROOT_ACCOUNT:
        // handled statically
        break;
      default:
        folder = QuickfileCommon.getFolderFromURI(uri);
        if (folder) {
          if (folder.isServer) {
            document.getElementById('quickfile.search.root.account.radio').value = uri;
            document.getElementById('quickfile.search.root.account.menulist').value = uri;
            document.getElementById('quickfile.search.root.radiogroup').selectedItem =
              document.getElementById('quickfile.search.root.account.radio');
          }
          else {
            var name = QuickfileCommon.getFolderRelativeName(folder);
            document.getElementById('quickfile.search.root.folder.radio').value = uri;
            document.getElementById('quickfile.search.root.textbox').value = name;
            document.getElementById('quickfile.search.root.radiogroup').selectedItem =
              document.getElementById('quickfile.search.root.folder.radio');
          }
        }
        else {
          document.getElementById('quickfile.search.root').value = 'msgaccounts:/';
        }
        break;
    }

    uri = document.getElementById('quickfile.defaultfolder.uri').value;
    folder = QuickfileCommon.getFolderFromURI(uri);
    if (folder) {
      var name = QuickfileCommon.getFolderRelativeName(folder);
      document.getElementById('quickfile.defaultfolder.textbox').value = name;
    }

    // sync default folder textbox enabled state
    this.onDefaultFolderEnableCommand();
  },

  onSearchRootAccountMenulistCommand: function _onSearchRootAccountMenulistCommand ()
  {
    var uri = document.getElementById('quickfile.search.root.account.menulist').selectedItem.value;

    document.getElementById('quickfile.search.root.account.radio').value = uri;
    document.getElementById('quickfile.search.root').value = uri;

    document.getElementById('quickfile.search.root.radiogroup').selectedItem =
      document.getElementById('quickfile.search.root.account.radio');
  },

  onDefaultFolderEnableCommand: function _onDefaultFolderEnableCommand ()
  {
    document.getElementById('quickfile.defaultfolder.textbox').disabled =
      ! document.getElementById('quickfile.defaultfolder.checkbox').checked;
  },

  onDefaultFolderTextEntered: function _onDefaultFolderTextEntered ()
  {
    document.getElementById('quickfile.defaultfolder.uri').value =
      document.getElementById('quickfile.defaultfolder.textbox').uriValue;
  },

  onSearchRootTextEntered: function _onSearchRootTextEntered ()
  {
    var uri = document.getElementById('quickfile.search.root.textbox').uriValue;

    document.getElementById('quickfile.search.root.folder.radio').value = uri;
    document.getElementById('quickfile.search.root').value = uri;

    document.getElementById('quickfile.search.root.radiogroup').selectedItem =
      document.getElementById('quickfile.search.root.folder.radio');
  }
};

function ensureValidOptions() {
  var searchRootUri = document.getElementById('quickfile.search.root').value;
  var defaultFolderEnabled = document.getElementById('quickfile.defaultfolder.enable').value;
  var defaultFolderUri = document.getElementById('quickfile.defaultfolder.uri').value;

  var defaultFolder = null;
  if (defaultFolderEnabled) {
    defaultFolder = QuickfileCommon.getFolderFromURI(defaultFolderUri);
    if (! defaultFolder) {
      // TODO: disable default folder when it's invalid
        alert("You cannot use a default folder which is not a valid folder");
        document.getElementById('quickfile.defaultfolder.enable').value = false;
        return false;
    }
  }

  switch (searchRootUri) {
    case QF_SEARCHROOT_ALL:
      break;
    case QF_SEARCHROOT_ACCOUNT:
      if (defaultFolderEnabled) {
        // TODO: disable default folder when msgaccount:/ is selected
        alert("You cannot use a default folder when your search root is the message account");
        document.getElementById('quickfile.defaultfolder.enable').value = false;
        return false;
      }
      break;
    default:
      var searchRootFolder = QuickfileCommon.getFolderFromURI(searchRootUri);
      if (defaultFolderEnabled && defaultFolder && ! searchRootFolder.isAncestorOf(defaultFolder)) {
        // TODO: disable default folder when root is not ancestor
        alert("You cannot use a default folder which is outside your search root heirarchy");
        document.getElementById('quickfile.defaultfolder.enable').value = false;
        return false;
      }
      break;
  }

  return true;
}